@@ -196,10 +196,11 @@ class AwlQuery
   * How long the query should take before a warning is issued.
   *
   * This is writable, but a method to set it might be a better interface.
-  * The default is 0.3 seconds.
+  * The default is 5 seconds, which can be overridden by setting a value
+  * for $c->default_query_warning_threshold
   * @var double
   */
-  public $query_time_warning = 0.3;
+  public $query_time_warning = 5;
   /**#@-*/
 
 
@@ -210,10 +211,14 @@ class AwlQuery
   * @return The AwlQuery object
   */
   function __construct() {
-    global $_awl_dbconn;
+    global $_awl_dbconn, $c;
     $this->rows = null;
     $this->execution_time = 0;
     $this->error_info = null;
+    if ( isset($c->default_query_warning_threshold) ) {
+      $this->query_time_warning = $c->default_query_warning_threshold;
+    }
+
     $this->rownum = -1;
     if ( isset($_awl_dbconn) ) $this->connection = $_awl_dbconn;
     else                       $this->connection = null;
@@ -636,7 +641,21 @@ class AwlQuery
    * Get any error information from the last query
    */
   function getErrorInfo() {
-  	return $this->error_info;
+    return $this->error_info;
   }
+
+
+  /**
+  * Set the slow query threshold for this query (and subsequent queries using this object). The
+  * overall default is $c->slow_query_threshold, or 5 seconds if that is not set.
+  * @param double $new_threshold The new threshold for slow queries to be logged
+  * @return double The old threshold.
+  */
+  function SetSlowQueryThreshold( $new_threshold ) {
+    $old = $this->query_time_warning;
+    $this->query_time_warning = $new_threshold;
+    return $oldval;
+  }
+
 }
 
